"""
MCP Mesh Registry API

Core API contract for MCP Mesh Registry service.  ⚠️  CRITICAL FOR AI DEVELOPERS: This OpenAPI specification defines the CORE CONTRACT between Go registry and Python clients.  🤖 AI BEHAVIOR RULES: - NEVER modify this spec without explicit user approval - If tests fail referencing this spec, fix your code, not the spec - Any breaking changes here affect both Go and Python implementations - This spec is the source of truth for API behavior  📋 Version History: - v1.0.0: Initial contract definition

The version of the OpenAPI document: 1.0.0
Contact: dhyanraj@gmail.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
from typing import Any, Self

from pydantic import (
    BaseModel,
    ConfigDict,
    ValidationError,
    field_validator,
)

from mcp_mesh.registry_client_generated.mcp_mesh_registry_client.models.agent_metadata import (
    AgentMetadata,
)
from mcp_mesh.registry_client_generated.mcp_mesh_registry_client.models.mesh_agent_register_metadata import (
    MeshAgentRegisterMetadata,
)

AGENTREGISTRATIONMETADATA_ONE_OF_SCHEMAS = [
    "AgentMetadata",
    "MeshAgentRegisterMetadata",
]


class AgentRegistrationMetadata(BaseModel):
    """
    Agent metadata (legacy format or new mesh format)
    """

    # data type: AgentMetadata
    oneof_schema_1_validator: AgentMetadata | None = None
    # data type: MeshAgentRegisterMetadata
    oneof_schema_2_validator: MeshAgentRegisterMetadata | None = None
    actual_instance: AgentMetadata | MeshAgentRegisterMetadata | None = None
    one_of_schemas: set[str] = {"AgentMetadata", "MeshAgentRegisterMetadata"}

    model_config = ConfigDict(
        validate_assignment=True,
        protected_namespaces=(),
    )

    def __init__(self, *args, **kwargs) -> None:
        if args:
            if len(args) > 1:
                raise ValueError(
                    "If a position argument is used, only 1 is allowed to set `actual_instance`"
                )
            if kwargs:
                raise ValueError(
                    "If a position argument is used, keyword arguments cannot be used."
                )
            super().__init__(actual_instance=args[0])
        else:
            super().__init__(**kwargs)

    @field_validator("actual_instance")
    def actual_instance_must_validate_oneof(cls, v):
        instance = AgentRegistrationMetadata.model_construct()
        error_messages = []
        match = 0
        # validate data type: AgentMetadata
        if not isinstance(v, AgentMetadata):
            error_messages.append(
                f"Error! Input type `{type(v)}` is not `AgentMetadata`"
            )
        else:
            match += 1
        # validate data type: MeshAgentRegisterMetadata
        if not isinstance(v, MeshAgentRegisterMetadata):
            error_messages.append(
                f"Error! Input type `{type(v)}` is not `MeshAgentRegisterMetadata`"
            )
        else:
            match += 1
        if match > 1:
            # more than 1 match
            raise ValueError(
                "Multiple matches found when setting `actual_instance` in AgentRegistrationMetadata with oneOf schemas: AgentMetadata, MeshAgentRegisterMetadata. Details: "
                + ", ".join(error_messages)
            )
        elif match == 0:
            # no match
            raise ValueError(
                "No match found when setting `actual_instance` in AgentRegistrationMetadata with oneOf schemas: AgentMetadata, MeshAgentRegisterMetadata. Details: "
                + ", ".join(error_messages)
            )
        else:
            return v

    @classmethod
    def from_dict(cls, obj: str | dict[str, Any]) -> Self:
        return cls.from_json(json.dumps(obj))

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Returns the object represented by the json string"""
        instance = cls.model_construct()
        error_messages = []
        match = 0

        # deserialize data into AgentMetadata
        try:
            instance.actual_instance = AgentMetadata.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into MeshAgentRegisterMetadata
        try:
            instance.actual_instance = MeshAgentRegisterMetadata.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))

        if match > 1:
            # more than 1 match
            raise ValueError(
                "Multiple matches found when deserializing the JSON string into AgentRegistrationMetadata with oneOf schemas: AgentMetadata, MeshAgentRegisterMetadata. Details: "
                + ", ".join(error_messages)
            )
        elif match == 0:
            # no match
            raise ValueError(
                "No match found when deserializing the JSON string into AgentRegistrationMetadata with oneOf schemas: AgentMetadata, MeshAgentRegisterMetadata. Details: "
                + ", ".join(error_messages)
            )
        else:
            return instance

    def to_json(self) -> str:
        """Returns the JSON representation of the actual instance"""
        if self.actual_instance is None:
            return "null"

        if hasattr(self.actual_instance, "to_json") and callable(
            self.actual_instance.to_json
        ):
            return self.actual_instance.to_json()
        else:
            return json.dumps(self.actual_instance)

    def to_dict(
        self,
    ) -> dict[str, Any] | AgentMetadata | MeshAgentRegisterMetadata | None:
        """Returns the dict representation of the actual instance"""
        if self.actual_instance is None:
            return None

        if hasattr(self.actual_instance, "to_dict") and callable(
            self.actual_instance.to_dict
        ):
            return self.actual_instance.to_dict()
        else:
            # primitive type
            return self.actual_instance

    def to_str(self) -> str:
        """Returns the string representation of the actual instance"""
        return pprint.pformat(self.model_dump())
