# flake8: noqa

# import apis into api package
from mcp_mesh.registry_client_generated.mcp_mesh_registry_client.api.agents_api import (
    AgentsApi,
)
from mcp_mesh.registry_client_generated.mcp_mesh_registry_client.api.health_api import (
    HealthApi,
)
